darkhistory.spec.spectrum.Spectrum
==================================

.. currentmodule:: darkhistory.spec.spectrum

.. autoclass:: Spectrum
   :members:
   :special-members:

   
   .. automethod:: __init__
